webbpsf\_ext.spectra.source\_spectrum
=====================================

.. currentmodule:: webbpsf_ext.spectra

.. autoclass:: source_spectrum
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~source_spectrum.__init__
      ~source_spectrum.bb_jy
      ~source_spectrum.fit_SED
      ~source_spectrum.func_resid
      ~source_spectrum.model_IRexcess
      ~source_spectrum.model_scale
      ~source_spectrum.plot_SED
   
   

   
   
   